import os

import requests
import pandas as pd



class Landslide:
    """Contains the NASA landslide data
       Atributes
       ---------
       df: pandas.DataFrame
            Dataframe with landslide data

       Methods
       -------
        summarize
            Returns summary statistics of the dataset
    """

    def __init__(self, subset=-1, verbose=False):
        """Instantiates the object and downloads the data
        # Arguments
            subset: the last row to load in the Dataframe
            verbose
        # Returns
            Dataframe with the data
        """

        if not os.path.exists('/tmp/landsliade_data.csv'):
            if verbose:
                print("Cache not found, downloading data...")
            try:
                with open(f'/tmp/landsliade_data.csv', 'w') as data:
                    r = requests.get('https://data.nasa.gov/api/views/dd9e-wu2v/rows.csv?accessType=DOWNLOAD')
                    if verbose:
                        print("Downloaded data")
                    lines = r.text.split('\n')[:subset]
                    for l in lines:
                        l += "\n"
                        data.write(l)
            except:
                os.remove('/tmp/landslide_data.csv')
                raise ConnectionError("You need an internet connection to download the data")
        
        df = pd.read_csv('/tmp/landsliade_data.csv')
        if verbose:
            print("Dataset loaded")
        self.df =  df
    
    def summarize(self):
        """Returns summary statistics of the dataset"""
        return self.df.describe()


if __name__ == '__main__':
    LS = Landslide(subset=100, verbose=True)
    print(LS.summarize())


import os

import requests
import pandas as pd


class Gosat:
    """Contains the GOSAT greenhouse gases concentration data
       Atributes
       ---------
       df: pandas.DataFrame
            Dataframe with gosat data

       Methods
       -------
        summarize
            Returns summary statistics of the dataset
    """
    
    def __init__(self, subset=-1, verbose=False, month='02', year='2019'):
        """Instantiates the object and downloads the data
        # Arguments
            year: a string with the year you want to download the data from 
            month: a string with the month you want to download the data from
            subset: the last row to load in the Dataframe
            verbose
        # Returns
            Dataframe with the data
        """

        if not os.path.exists(f'/tmp/gosat{year}{month}.tsv'):
            if verbose:
                print("Cache not found, downloading data...")
            try:
                with open(f'/tmp/gosat{year}{month}.tsv', 'w') as data:
                    r = requests.get(f'https://www.eorc.jaxa.jp/GOSAT/GPCG/download/data-g2-{year}{month}.txt')
                    if verbose:
                        print("Downloaded data")
                    lines = r.text.split('\n')[11:subset]
                    for l in lines:
                        l = '\t'.join(l.split()) + "\n"
                        data.write(l)
            except:
                os.remove(f'/tmp/gosat{year}{month}.tsv')
                raise ConnectionError("You need an internet connection to download the data")
        
        df = pd.read_csv(f'/tmp/gosat{year}{month}.tsv', '\t')
        if verbose:
            print("Dataset loaded")
        self.df = df
    
    def summarize(self):
        """Returns summary statistics of the dataset"""
        return self.df.describe()


if __name__ == '__main__':
    GS = Gosat(subset=100, verbose=True)
    print(GS.summarize())


import os

import requests
import pandas as pd


class MortalityNatality:
    """Contains the ESA Mortality and Natality Data
       Atributes
       ---------
       df: pandas.DataFrame
            Dataframe with mortality and natality data

       Methods
       -------
        summarize
            Returns summary statistics of the dataset
    """

    def __init__(self, subset=-1, verbose=False):
        """Instantiates the object and downloads the data
        # Arguments
            subset: the last row to load in the Dataframe
            verbose
        # Returns
            Dataframe with the data
        """
        
        if not os.path.exists('/tmp/mortality_natality.tsv'):
            if verbose:
                print("Cache not found, downloading data...")
            try:
                with open('/tmp/mortality_natality.tsv', 'w') as data:
                    r = requests.get('https://ec.europa.eu/eurostat/estat-navtree-portlet-prod/BulkDownloadListing?file=data/urb_lfermor.tsv.gz&unzip=true')
                    if verbose:
                        print("Downloaded data")
                    lines = r.text.split('\n')[:subset]
                    for l in lines:
                        l += "\n"
                        data.write(l)
            except:
                os.remove('/tmp/mortality_natality.tsv')
                raise ConnectionError("You need an internet connection to download the data")
                
    
        df = pd.read_csv('/tmp/mortality_natality.tsv', '\t')
        if verbose:
            print("Dataset loaded")
        self.df = df

    def summarize(self):
        """Returns summary statistics of the dataset"""
        return self.df.describe()
    


if __name__ == '__main__':
    MN = MortalityNatality(subset=100, verbose=True)
    print(MN.summarize())


headers = {'User-Agent':'Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/81.0.4044.92 Safari/537.36'}

login_data = {
        'utf8': '✓',
        'client_id': 'YQOhivHfMTau88rjbMOVyg',
        'redirect_uri': 'https://daac.ornl.gov/cgi-bin/urs/urs_logon_proc.pl',
        'response_type': 'code',
        'state': 'https://daac.ornl.gov/',
        'stay_in': '1',
        'commit': 'Log in',
}



import os

import requests
import pandas as pd
from bs4 import BeautifulSoup as soup
from .earthdata_login import login_data, headers


class Atmospheric:
    """Contains the NASA Atmospheric data
       Atributes
       ---------
       df: pandas.DataFrame
            Dataframe with atmospheric data

       Methods
       -------
        summarize
            Returns summary statistics of the dataset
    """
    
    def __init__(self, username, password, subset=-1, verbose=False):
        """Instantiates the object and downloads the data
        # Arguments
            subset: the last row to load in the Dataframe
            verbose
        # Returns
            Dataframe with the data
        """

        if not os.path.exists('/tmp/atmosferic_gas_concentration.csv'):
            if verbose:
                print("Cache not found, downloading data...")
            try:
                with open('/tmp/atmosferic_gas_concentration.csv', 'w') as data:
                    with requests.Session() as s:
                        login_url = 'https://urs.earthdata.nasa.gov/oauth/authorize?client_id=YQOhivHfMTau88rjbMOVyg&response_type=code&redirect_uri=https://daac.ornl.gov/cgi-bin/urs/urs_logon_proc.pl&state=https%3A%2F%2Fdaac.ornl.gov%2F'
                        download_url = 'https://daac.ornl.gov/daacdata/above/ABoVE_Atmospheric_Flask_Data/data/ABoVE_april-nov_2017_flask_data.csv'
                        
                        r = s.get(login_url, headers=headers)
                        html = soup(r.content, "lxml")

                        auth = html.find("input", attrs={'name':'authenticity_token'})['value']
                        login_data['authenticity_token'] = auth
                        login_data['username'] = username
                        login_data['password'] = password

                        s.post('https://urs.earthdata.nasa.gov/login', data=login_data, headers=headers)
                        r = s.get(download_url, headers=headers)
            
                    if verbose:
                        print("Downloaded data")
                    lines = r.text.split('\n')[:subset]
                    for l in lines:
                        l += "\n"
                        data.write(l)
            except:
                os.remove('atmosferic_gas_concentration.csv')
                raise ConnectionError("You need an internet connection to download the data")
    
        df = pd.read_csv('/tmp/atmosferic_gas_concentration.csv')
        if verbose:
            print("Dataset loaded")
        self.df = df
    
    def summarize(self):
        """Returns summary statistics of the dataset"""
        return self.df.describe()

if __name__ == '__main__':
    AG = Atmospheric(subset=100, verbose=True, username='username', password='password')
    print(AG.summarize())


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="covidata",
    version="0.0.5",
    author="Control-space",
    author_email="author@example.com",
    description="Easily access NASA, ESA and JAXA data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/lusmoura/Nasa-space-apps",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=['pandas', 
                    'requests',
                    'beautifulsoup4',
                    ' lxml']
)


import os

import requests
import pandas as pd


class OpenData:
    """Contains the EU open data Covid case distribution
       Atributes
       ---------
       df: pandas.DataFrame
            Dataframe with Covid-19 case distribution

       Methods
       -------
        summarize
            Returns summary statistics of the dataset
    """

    def __init__(self, subset=-1, verbose=False):
        """Instantiates the object and downloads the data
        # Arguments
            subset: the last row to load in the Dataframe
            verbose
        # Returns
            Dataframe with the data
        """
        
        if not os.path.exists('/tmp/opendata.csv'):
            if verbose:
                print("Cache not found, downloading data...")
            try:
                with open(f'/tmp/opendata.csv', 'w') as data:
                    r = requests.get(f'https://opendata.ecdc.europa.eu/covid19/casedistribution/csv')
                    if verbose:
                        print("Downloaded data")
                    lines = r.text.split('\r\n')[:subset]
                    for l in lines:
                        l += '\n'
                        data.write(l)
            except:
                os.remove('/tmp/opendata.csv')
                raise ConnectionError("You need an internet connection to download the data")
        
        df = pd.read_csv('/tmp/opendata.csv')
        if verbose:
            print("Dataset loaded")
        self.df = df
    
    def summarize(self):
        """Returns summary statistics of the dataset"""
        return self.df.describe()


if __name__ == '__main__':
    OD = OpenData(subset=100, verbose=True)
    print(OD.summarize())